@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_dynamodb._jsii
@@ -24,9 +24,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-lambda-event-sources",
-    "1.53.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-lambda-event-sources@1.53.0.jsii.tgz",
+    "aws-lambda-event-sources@1.64.0.jsii.tgz",
 )
 
 __all__ = [
